@@ -3,9 +3,10 @@
 #' @param merge_by_chunk_id the merge is performed by chunk id
 #' @param overwrite overwrite output directory
 #' @param .progress Show progress or not. Defaults to FALSE
+#' @param suffix see dplyr::XXX_join
+#' @param keep see dplyr::XXX_join
 #' @param ... same as dplyr's joins
 #' @rdname join
-#' @importFrom rlang quo enquos
 #' @importFrom dplyr anti_join left_join full_join semi_join inner_join
 #' @return disk.frame or data.frame/data.table
 #' @export
@@ -29,11 +30,11 @@ anti_join.disk.frame <- function(x, y, by=NULL, copy=FALSE, ..., outdir = tempfi
   overwrite_check(outdir, overwrite)
   
   if("data.frame" %in% class(y)) {
-    quo_dotdotdot = enquos(...)
-    cmap_dfr.disk.frame(x, ~{
-      code = quo(anti_join(.x, y, by = by, copy = copy, !!!quo_dotdotdot))
-      rlang::eval_tidy(code)
+    tmp = cmap.disk.frame(x, ~{
+      anti_join(.x, y, by = by, copy = copy, ...)
     }, .progress = .progress)
+    
+    return(tmp)
   } else if("disk.frame" %in% class(y)) {
     if(is.null(merge_by_chunk_id)) {
       stop("both x and y are disk.frames. You need to specify merge_by_chunk_id = TRUE or FALSE explicitly")
@@ -47,12 +48,12 @@ anti_join.disk.frame <- function(x, y, by=NULL, copy=FALSE, ..., outdir = tempfi
     if (merge_by_chunk_id == FALSE) {
       warning("merge_by_chunk_id = FALSE. This will take significantly longer and the preparations needed are performed eagerly which may lead to poor performance. Consider making y a data.frame or set merge_by_chunk_id = TRUE for better performance.")
       
-      x = hard_group_by(x, by, nchunks = max(ncy,ncx), overwrite = TRUE)
-      y = hard_group_by(y, by, nchunks = max(ncy,ncx), overwrite = TRUE)
+      ncxy = max(ncy,ncx)
+      x = rechunk(x, shardby=by, nchunks = ncxy, outdir=tempfile(fileext = ".jdf"), overwrite = FALSE)
+      y = rechunk(y, shardby=by, nchunks =ncxy, outdir=tempfile(fileext = ".jdf"), overwrite = FALSE)
       return(anti_join.disk.frame(x, y, by, copy = copy, outdir = outdir, merge_by_chunk_id = TRUE, overwrite = overwrite))
     } else if ((identical(shardkey(x)$shardkey, "") & identical(shardkey(y)$shardkey, "")) | identical(shardkey(x), shardkey(y))) {
       res = cmap2.disk.frame(x, y, ~{
-      #res = cmap2(x, y, ~{
         if(is.null(.y)) {
           return(.x)
         } else if (is.null(.x)) {
