@@ -23,15 +23,14 @@
 #' delete(cars.df)
 #' @export
 #' @rdname collect
-collect.disk.frame <- function(x, ..., parallel = !is.null(attr(x,"lazyfn"))) {
+collect.disk.frame <- function(x, ..., parallel = !is.null(attr(x,"recordings"))) {
   cids = get_chunk_ids(x, full.names = TRUE, strip_extension = FALSE)
-  #cids = as.integer(get_chunk_ids(x))
   if(nchunks(x) > 0) {
     if(parallel) {
-      future.apply::future_lapply(cids, function(.x) {
-                              get_chunk(x, .x, full.names = TRUE)
-      }, future.seed = TRUE) %>% 
-        rbindlist()
+      tmp = future.apply::future_lapply(cids, function(.x) {
+          get_chunk(x, .x, full.names = TRUE)
+      }, future.seed = TRUE)
+      return(rbindlist(tmp))
     } else {
       purrr::map_dfr(cids, ~get_chunk(x, .x, full.names = TRUE))
     }
@@ -52,24 +51,26 @@ collect.disk.frame <- function(x, ..., parallel = !is.null(attr(x,"lazyfn"))) {
 #' 
 #' # clean up
 #' delete(cars.df)
-collect_list <- function(x, simplify = FALSE, parallel = !is.null(attr(x,"lazyfn"))) {
+collect_list <- function(x, simplify = FALSE, parallel = !is.null(attr(x,"recordings")), ...) {
+  # get the chunk ids
   cids = get_chunk_ids(x, full.names = TRUE, strip_extension = FALSE)
   
-  
-  if(nchunks(x) > 0) {
-    res <- NULL
+  if(length(cids) > 0) {
+    list_of_results = NULL
     if (parallel) {
-      #res = furrr::future_map(1:nchunks(x), ~get_chunk(x, .x))
-      res = future.apply::future_lapply(cids, function(.x) {
+      list_of_results = future.apply::future_lapply(cids, function(.x) {
         get_chunk(x, .x, full.names = TRUE)
       }, future.seed=TRUE)
     } else {
-      res = purrr::map(cids, ~get_chunk(x, .x, full.names = TRUE))
+      list_of_results = lapply(cids, function(cid) {
+        get_chunk(x, cid, full.names = TRUE)
+      })
     }
+    
     if (simplify) {
-      return(simplify2array(res))
+      return(simplify2array(list_of_results))
     } else {
-      return(res)
+      return(list_of_results)
     }
   } else {
     list()
