@@ -25,8 +25,9 @@ names.disk.frame <- function(x, ...) {
 #' @export
 colnames.disk.frame <- function(x, ...) {
   res = attr(x, "path", exact=TRUE) %>% 
-    fs::dir_ls(type="file")
-  if(is.null(attr(x, "lazyfn"))) {
+    list.files(full.names = TRUE)
+  
+  if(is.null(attr(x, "recordings"))) {
     if(length(res) == 0) {
       return(vector("character"))
     }
@@ -42,4 +43,4 @@ colnames.disk.frame <- function(x, ...) {
 #' @export
 colnames.default <- function(x, ...) {
   base::colnames(x, ...)
-}
\ No newline at end of file
+}
